%% analyse bahvioral data
clear;
close all;
clc;

%% options
% plot individual performance?
plotIndividual = 0;

% set paths
addpath('Z:\Florian\tMentRotNew\analysis\scripts\functions');
SUBJ = {'01', '02', '03', '04', '05', '06', '07', '08', '09', '10', '11', '12', '13', '14', '15', '16', '17', '18', '19', '20', '21', '22', '23', '24', '25'};
PATHOUT = 'Z:\Florian\tMentRotNew\analysis\stats\';
mkdir(PATHOUT);

% pre-allocate variables
GROUP.errorRate = zeros(7,length(SUBJ));
GROUP.RTs = zeros(4,7,length(SUBJ));
GROUP.misses = zeros(1,length(SUBJ));
 
idxStim = zeros(1,length(SUBJ));
idxSham = zeros(1,length(SUBJ));
idxMale = zeros(1,length(SUBJ));
idxFem = zeros(1,length(SUBJ));

for sbj = 1:length(SUBJ)
    
    % load dataset
    PATHIN = ['Z:\Florian\tMentRotNew\analysis\rawdir\tm', SUBJ{sbj}, 'a\'];
    filename = ['VP_', SUBJ{sbj}, '.mat'];
    
    load([PATHIN, filename]);
    
    
    %% assign group
    if strcmp(BEHAV.condition, 'c')
        idxSham(sbj) = 1;
    elseif strcmp(BEHAV.condition, 's')
        idxStim(sbj) = 1;
    end
    
    %% assign gender
    if strcmp(BEHAV.sex, 'm')
        idxMale(sbj) = 1;
    elseif strcmp(BEHAV.sex, 'f')
        idxFem(sbj) = 1;
    end
    
    %% Analize performance
    BEHAV.errorRate = zeros(7,1);
    BEHAV.RTs = zeros(7,4);
    BEHAV.stds = zeros(7,4);
    GROUP.misses(sbj) = sum(BEHAV.stimLog.RT == 0);
    i = 1;
    j = 1;
    while i < size(BEHAV.stimLog, 1)
        
        BEHAV.errorRate(j,1) = sum(BEHAV.stimLog.correct(i:i + 47))/48;
        temp = BEHAV.stimLog(i:i+47, :);
        temp = temp(temp.correct == 1, :);
        
        BEHAV.RTs(j,1) = mean(temp.RT(temp.angle == 0));
        BEHAV.stds(j,1) = std(temp.RT(temp.angle == 0), [],1);
        BEHAV.RTs(j,2) = mean(temp.RT(temp.angle == 50));
        BEHAV.stds(j,2) = std(temp.RT(temp.angle == 50), [],1);
        BEHAV.RTs(j,3) = mean(temp.RT(temp.angle == 100));
        BEHAV.stds(j,3) = std(temp.RT(temp.angle == 100), [],1);
        BEHAV.RTs(j,4) = mean(temp.RT(temp.angle == 150));
        BEHAV.stds(j,4) = std(temp.RT(temp.angle == 150), [],1);
        
        
        i  = i + 48;
        j = j + 1;
    end
    
    BEHAV.RTs = BEHAV.RTs';
    BEHAV.stds = BEHAV.stds';
    
    if plotIndividual == 1
        figure;
        subplot(2,1,1);
        bar(BEHAV.errorRate*100);
        title(['Error Rate [%] ', SUBJ{sbj}, BEHAV.condition]);
        subplot(2,1,2);
        errorbar(repmat((0:50:150)',1,7),BEHAV.RTs,BEHAV.stds)
        legend('1', '2', '3', '4', '5', '6', '7');
        title('RTs');
    end
    
    
    GROUP.errorRate(:,sbj) = BEHAV.errorRate;
    GROUP.RTs(:,:,sbj) = BEHAV.RTs;
    GROUP.freq(sbj) = BEHAV.frequency;
    GROUP.amp(sbj) = BEHAV.amplitude;
end 

% get group indices
idxStim = find(idxStim);
idxSham = find(idxSham);
idxMale = find(idxMale);
idxFem = find(idxFem);

% calculate normalized error rate
GROUP.normErrorRate = (GROUP.errorRate ./ repmat(GROUP.errorRate(1,:), 7, 1)) * 100;

GROUP.normErrorRate = GROUP.normErrorRate - 100;

% normalize RTs

for e = 1:7

GROUP.normRTs(:,e,:) = GROUP.RTs(:,e,:) ./ GROUP.RTs(:,1,:)*100;

end

GROUP.normRTs = GROUP.normRTs - 100;

% average results for plotting
GROUP.AVnormRTs = squeeze(mean(GROUP.normRTs, 1));
GROUP.grAVnormRTs = mean(GROUP.AVnormRTs(:,idxSham), 2);
GROUP.grAVnormRTs(:,2) = mean(GROUP.AVnormRTs(:,idxStim), 2);

GROUP.SEMAVnormRTs = sem(GROUP.AVnormRTs(:,idxSham),[], 2);
GROUP.SEMAVnormRTs(:,2) = sem(GROUP.AVnormRTs(:,idxStim),[], 2);

GROUP.AvRTsStim = mean(GROUP.RTs(:,:,idxStim),3);
GROUP.AvRTsSham = mean(GROUP.RTs(:,:,idxSham),3);



GROUP.AvErrorRate(:,2) = mean(GROUP.errorRate(:,idxStim),2);
GROUP.AvErrorRate(:,1) = mean(GROUP.errorRate(:,idxSham),2);
GROUP.SEMErrorRate(:,2) = sem(GROUP.errorRate(:,idxStim), [],2);
GROUP.SEMErrorRate(:,1) = sem(GROUP.errorRate(:,idxSham),[],2);


GROUP.AvNormER(:,2) = mean(GROUP.normErrorRate(:,idxStim),2);
GROUP.AvNormER(:,1) = mean(GROUP.normErrorRate(:,idxSham),2);
GROUP.SEMNormER(:,2) = sem(GROUP.normErrorRate(:,idxStim),[],2);
GROUP.SEMNormER(:,1) = sem(GROUP.normErrorRate(:,idxSham),[],2);
GROUP.SEMStim = sem(GROUP.RTs(:,:,idxStim),[],3);
GROUP.SEMSham = sem(GROUP.RTs(:,:,idxSham),[],3);




GROUP.GrandErr = mean(GROUP.normErrorRate(2:end,:),1);

GROUP.sexErr(:,1) = mean(GROUP.GrandErr(idxFem));
GROUP.sexErr(:,2) = mean(GROUP.GrandErr(idxMale));
GROUP.sexErrSEM(:,1) = sem(GROUP.GrandErr(idxFem), [],2);
GROUP.sexErrSEM(:,2) = sem(GROUP.GrandErr(idxMale),[],2);

GROUP.grErr(:,1) = mean(GROUP.GrandErr(idxStim));
GROUP.grErr(:,2) = mean(GROUP.GrandErr(idxSham));
GROUP.grErrSEM(:,1) = sem(GROUP.GrandErr(idxStim), [],2);
GROUP.grErrSEM(:,2) = sem(GROUP.GrandErr(idxSham),[],2);

% plot results

plotWindow = 1:7;  


incrFig = figure;
subplot(2,2,2);
barwitherr(GROUP.sexErrSEM', GROUP.sexErr', 0.8, 'stacked', 'LineWidth', 1); axis([0.5 2.5 -10 10]);
%title('Performance Improvement [%]', 'FontSize', 18);
%ylabel('performance increase [%]', 'FontSize', 24);
set(gca, 'XTickLabel', {'Females', 'Males'}, 'FontSize', 22, 'LineWidth', 2);

%grdiff = figure;
subplot(2,2,1);
barwitherr(GROUP.grErrSEM', GROUP.grErr', 0.8, 'stacked', 'LineWidth', 1); axis([0.5 2.5 -10 10]);
%title('Performance Improvement [%]', 'FontSize', 18);
ylabel('performance increase [%]', 'FontSize', 24);
set(gca, 'XTickLabel', {'Stimulation', 'Sham'}, 'FontSize', 22, 'LineWidth', 2);

subplot(2,2,3:4);
barwitherr(GROUP.SEMNormER, GROUP.AvNormER, 0.8, 'LineWidth', 1); hold on; axis([0 8 -10 10]);
%legend(['Sham N = ', num2str(size(idxSham,2))], ['Stim N = ', num2str(size(idxStim,2))], 'Location', 'NorthWest');
legend('Sham', 'Stim', 'Location', 'NorthWest');
%title('Performance Improvement [%]', 'FontSize', 18);
ylabel('performance increase [%]', 'FontSize', 24);
set(gca, 'XTickLabel', {'Baseline', 'Block 1', 'Block 2', 'Block 3', 'Block 4', 'Block 5', 'Block 6', 'Block 7'}, 'FontSize', 22, 'LineWidth', 2);

figure;
errorbar(repmat((0:50:150)',1,size(GROUP.AvRTsStim(:,plotWindow),2)),GROUP.AvRTsStim(:,plotWindow),GROUP.SEMStim(:,plotWindow)); hold on;
errorbar(repmat((0:50:150)',1,size(GROUP.AvRTsSham(:,plotWindow),2)),GROUP.AvRTsSham(:,plotWindow),GROUP.SEMSham(:,plotWindow), ':')
legend('1', '2', '3', '4', '5', '6', '7', '8');
title('RTs');

figure;
barwitherr(GROUP.SEMErrorRate*100,GROUP.AvErrorRate*100); hold on; axis([0 8 80 100]);
%legend(['Sham N = ', num2str(size(idxSham,2))], ['Stim N = ', num2str(size(idxStim,2))]);
legend('Sham', 'Stim');
title('performance [%]', 'FontSize', 18);

GROUP.amp = GROUP.amp*4;

GROUP.rawRTs = squeeze(mean(GROUP.RTs,1));



meanAmp = mean(GROUP.amp);
meanFreq = mean(GROUP.freq);
stdAmp = std(GROUP.amp);
stdFreq = std(GROUP.freq);

figure;
subplot(2,2,3:4);
barwitherr(GROUP.SEMAVnormRTs, GROUP.grAVnormRTs, 0.8, 'grouped', 'LineWidth', 1); %axis([0.5 2.5 0 25]);
%title('Performance Improvement [%]', 'FontSize', 18);
ylabel('RT change [%]', 'FontSize', 24);
set(gca, 'XTickLabel', {'Baseline', 'Block 1', 'Block 2', 'Block 3', 'Block 4', 'Block 5', 'Block 6', 'Block 7'}, 'FontSize', 22, 'LineWidth', 2);

outpRts = GROUP.AVnormRTs';

csvwrite([PATHOUT, 'normRTs.csv'], outpRts);
csvwrite([PATHOUT, 'ErrRate.csv'], GROUP.errorRate');
csvwrite([PATHOUT, 'NormErrRate.csv'], GROUP.normErrorRate');
csvwrite([PATHOUT, 'rawRTs.csv'], GROUP.rawRTs');

fprintf('Measured %2i females and %2i males! \n %2i stimulated, %2i sham \n', length(idxFem), length(idxMale), length(idxStim), length(idxSham));
