%% simulate ERD
% this script simulates the effect of a residual artifact on relative power
% change (ERD/ERS) and absolute power difference. R is power in a reference period, A power after stimulus onset 
clear;
close all;
clc;

FontSize = 16;

N = 10000; % number of datapoints to simulate
%R = 10:1:100;
R = rand(1,N)*100; % random number between 0 and 100
A = R.*rand(1,N); % random number between 0 and 100, smaller than R
%A = ones(1,length(R))*10;
idxArt = rand(1,length(R))> 0.5; % randomly select ~half of the sample for artifact contamination
Artfkt = zeros(1,length(R));
Artfkt(idxArt) = 1;
Artfkt = Artfkt.*(rand(1,length(Artfkt))*150); % add artifact, random number between 0 and 150
%Artfkt = Artfkt*25;
%R(idxArt) = R(idxArt)+10;

% calculate ERD and ER (power difference) without artifact
ERD = (R-A)./R*100;
ER = R-A;

wA = 1*rand(1,N)*0.2+1; % random difference between pre and post stimulus artifact
wR = 1*rand(1,N)*0.2+1;

% calculate ERD and ER with artifact.
ERDart = ((R+Artfkt.*wR)-(A+Artfkt.*wA)) ./ (R+Artfkt.*wR)*100;
ERart = (R+Artfkt.*wR) - (A+Artfkt.*wA);

% plot Results:
% ERD is systematically underestimated in the prence of an artifact. ER
% becomes more noisy, but jitters rather stable around the true ER.
figure;

subplot(3,2,1);
scatter(A, R,[], ERD, 'filled'); colormap(jet);
ylabel('R [a.u.]', 'FontSize', FontSize);
xlabel('A [a.u.]', 'FontSize', FontSize);
title('ERD with increasing Pre- and Post-Stimulus Power', 'FontSize', FontSize);
c=colorbar;
c.Label.String = 'ERD [%]';
c.Label.FontSize = FontSize;
c.Limits = [0 100];
c.Ticks = 0:20:100;
set(gca, 'FontSize', FontSize);

subplot(3,2,2);
scatter(A, R, [], ER, 'filled'); colormap(jet);
ylabel('R [a.u.]', 'FontSize', FontSize);
xlabel('A [a.u.]', 'FontSize', FontSize);
title('ER\Delta_P_o_w with increasing Pre- and Post-Stimulus Power', 'FontSize', FontSize);
c=colorbar;
c.Label.String = 'ER\Delta_P_o_w [a.u.]';
c.Label.FontSize = FontSize;
c.Limits = [0 100];
c.Ticks = 0:20:100;
set(gca, 'FontSize', FontSize);

subplot(3,2,3);
plot(ER(idxArt),ERD(idxArt), 'k.'); hold on;
plot(ER(~idxArt),ERD(~idxArt), 'r.');
xlabel('ER\Delta_P_o_w [a.u.]', 'FontSize', FontSize);
ylabel('ERD [%]', 'FontSize', FontSize);
c = corr([ER; ERD]');
title(['ERD vs. ER\Delta_P_o_w without artifact r = ', num2str(c(2))], 'FontSize', FontSize);
legend('Sham', 'Stimulation (without artifact)', 'location', 'SouthEast');
set(gca, 'FontSize', FontSize);

subplot(3,2,4);
plot(ERart(~idxArt), ERDart(~idxArt), '.k'); hold on;
plot(ERart(idxArt), ERDart(idxArt), 'r.');
xlabel('ER\Delta_P_o_w [a.u.]', 'FontSize', FontSize);
ylabel('ERD [%]', 'FontSize', FontSize);
c = corr([ERart; ERDart]');
title(['ERD vs. ER\Delta_P_o_w with artifact [50% of datapoints] r = ' num2str(c(2))], 'FontSize', FontSize);
legend('Sham', 'Stimulation', 'location', 'SouthEast');
set(gca, 'FontSize', FontSize);

subplot(3,2,5);
plot(ERD(~idxArt), ERDart(~idxArt), '.k'); hold on;
plot(ERD(idxArt), ERDart(idxArt), '.r'); 
xlabel('ERD [%]', 'FontSize', FontSize);
ylabel('ERD with artifact [%]', 'FontSize', FontSize);
c = corr([ERD; ERDart]');
title(['ERD vs. ERD with artifact r = ', num2str(c(2))], 'FontSize', FontSize); 
legend('Sham', 'Stimulation', 'location', 'NorthWest');
set(gca, 'FontSize', FontSize);

subplot(3,2,6);
plot(ER(idxArt), ERart(idxArt), '.r'); hold on;
plot(ER(~idxArt), ERart(~idxArt), '.k'); 
xlabel('ER\Delta_P_o_w [a.u.]', 'FontSize', FontSize);
ylabel('ER\Delta_P_o_w with artifact [a.u.]', 'FontSize', FontSize);
c = corr([ER; ERart]');
title(['ER\Delta_P_o_w vs. ER\Delta_P_o_w with artifact r = ', num2str(c(2))], 'FontSize', FontSize); 
legend('Sham', 'Stimulation', 'location', 'NorthWest');
set(gca, 'FontSize', FontSize);

disp('ERD vs. ER without artefact');
corr([ERD; ER]')
disp('ERD vs. ER with artefact');
corr([ERDart; ERart]')
disp('ERD vs. ERD with artefact');
corr([ERD; ERDart]')
disp('ER vs. ER with artefact');
corr([ER; ERart]')

