clear;
close all;
clc;

MAINPATH = 'Z:\Florian\tMentRotNew\analysis\';
PATHINMRI = [MAINPATH, 'mri\'];
PATHINQUAT = [MAINPATH, 'resampled\'];
PATHOUT = [MAINPATH, 'mri\'];
addpath('Z:\Florian\fieldtrip');

ft_defaults;

optimizeGrid = 0;

%SUBJ = {'01', '02', '03', '04', '05', '06', '07', '08', '09', '10', '11', '12', '13', '14', '15', '16', '17', '18', '19', '20', '21', '22', '23', '24', '25'};
%SUBJ = {'12', '13', '14', '15', '16', '17', '18', '19', '20', '21', '22', '23', '24', '25'};
SUBJ = {'02'};

%% optimize template grid...
load mni_grid_1_5_cm_889pnts.mat;
load standard_mri.mat

insideDipoles = zeros(1,length(SUBJ));
for sbj = 1:length(SUBJ)
    
    resFig = figure;
    
    PATHINMEG = [MAINPATH, 'rawdir\tm', SUBJ{sbj}, 'a\'];
    
    filename = ['tm', SUBJ{sbj}, 'a2.fif'];
    
    shape = ft_read_headshape([PATHINMEG, filename]);
    sens = ft_read_sens([PATHINMEG, filename]);
    
    shape = ft_convert_units(shape, 'mm');
    sens = ft_convert_units(sens, 'mm');
    
    load([PATHINQUAT, 'tm_', SUBJ{sbj}, '_rs.mat']);
    
    cfg = [];
    cfg.channel = 'QUAT*';
    
    data = ft_selectdata(cfg,data);
    
    figure(resFig);
    subplot(3,7,[1 4]);
    plot(data.time{1}/60, data.trial{1}(1:6,:), '-');
    title('estimated head movements');
    legend('ax', 'ay', 'az', 'x', 'y', 'z');
    xlabel('time [min]');
    %% get quaternions and compute headshape position in head frame
    
    quatVec = zeros(1,7);
    quatVec(2:end) = data.trial{1}(1:6,10);
    quatVec(1) = sqrt(1-(quatVec(2)^2 + quatVec(3)^2 + quatVec(4)^2));
    
    M1 = quaternion(quatVec);
    %     device = sens;
    %     shape.fid.pos(4,:) = [0 0 0];
    %     DVShape = shape;
    
    
    %     DVShape.pos = ft_warp_apply(inv(M1), shape.pos, 'homogenous');
    %     DVShape.fid.pos = ft_warp_apply(inv(M1), shape.fid.pos, 'homogenous');
    %     device.chanpos = ft_warp_apply(inv(M1), sens.chanpos, 'homogenous');
    
    %     figure;
    %     subplot(1,2,1);
    %     ft_plot_sens(sens, 'coiltype', 'o', 'coilsize', 10); hold on;
    %     ft_plot_mesh(shape.fid.pos, 'vertexcolor', 'r');
    %     plot3(0,0,0, 'r.')
    %     subplot(1,2,2);
    %     ft_plot_sens(device, 'coiltype', 'o', 'coilsize', 10); hold on;
    %     ft_plot_mesh(DVShape.fid.pos, 'vertexcolor', 'g');
    
    %% now get quaternions from onset of each Block
    
    idxTRL = [EVENTS.value] == 12;
    
    idxTRL = find(idxTRL);
    
    idxBlk = 1:48:length(idxTRL);
    
    idxTRLEnd = idxTRL(idxBlk);
    idxBlk(2) = idxBlk(2)+3;
    idxTRLStart = idxTRL(idxBlk);
    
    
    idxBlockStart = [EVENTS(idxTRLStart).sample];
    idxBlockEnd = [EVENTS(idxTRLEnd).sample]+600*data.fsample-1;
    
    quatVec = zeros(length(idxTRLStart),7);
    
    for i = 1:length(idxBlockStart)
        
        quatVec(i,2:end) = median(data.trial{1}(1:6,idxBlockStart(i):idxBlockEnd(i)),2);
        quatVec(i,1) = sqrt(1 - (quatVec(i,2).^2 + quatVec(i,3).^2 + quatVec(i,4).^2));
        
    end
    %     figure;
    %     plot(quatVec, '.-')
    
    %% calculate homogenous transformation matrices from quaternions
    M = cell(1,7);
    AdptShape = M;
    for blk = 1:7
        
        %% Step 1 transform from head frame to actual position
        M{blk} = quaternion(quatVec(blk,:));
        
        AdptShape{blk} = shape;
        AdptShape{blk}.pos = ft_warp_apply(inv(M{blk}), shape.pos, 'homogenous');
        AdptShape{blk}.fid.pos = ft_warp_apply(inv(M{blk}), shape.fid.pos, 'homogenous');
        
        %% Step 2 transform back to head frame using the initial quaternions
        AdptShape{blk}.pos = ft_warp_apply(M1, AdptShape{blk}.pos, 'homogenous');
        AdptShape{blk}.fid.pos = ft_warp_apply(M1, AdptShape{blk}.fid.pos, 'homogenous');
        
    end
    
    AdptShape = cellfun(@(x) ft_convert_units(x, 'mm'), AdptShape, 'UniformOutput', 0);
    
    filename = ['tm', SUBJ{sbj}, '_mri.mat'];
    
    load([PATHINMRI,filename])
    
    resliced = ft_volumereslice([], resliced);
    
    resliced.coordsys = 'ras';
    resliced = ft_convert_units(resliced, 'mm');
    
    cfg = [];
    %cfg.output = {'brain', 'scalp'};
    cfg.output = 'scalp';
    %cfg.brainsmooth = 'no';
    
    scalpSeg = ft_volumesegment(cfg, resliced);
    
    cfg.output = 'brain';
    
    brainSeg = ft_volumesegment(cfg, resliced);
    
    scalpSeg = ft_convert_units(scalpSeg, 'mm');
    brainSeg = ft_convert_units(brainSeg, 'mm');
    
    cfg = [];
    cfg.method = 'singleshell';
    cfg.tissue = 'scalp';
    hdmScalp = ft_prepare_headmodel(cfg,scalpSeg);
    
    figure(resFig);
    subplot(3,7,[5 7]);
    ft_plot_sens(sens, 'coil', 1, 'style', 'ko', 'coildiameter', 10); hold on; axis tight;
    ft_plot_mesh(shape.fid.pos)
    cellfun(@(x) ft_plot_mesh(x.fid.pos, 'vertexcolor', 'r'), AdptShape);
    view([-148 6])
    
    if ismember(SUBJ{sbj}, {'02','05'});
        
        % perform automatic coregistration based on headshape
        cfg=[];
        cfg.method                = 'headshape';
        %cfg.inputfile             = [PATHINMRI,filename];
        cfg.headshape             = AdptShape{blk};
        cfg.viewresult            = 'no';
        cfg.headshape.icp         = 'no';
        %cfg.headshape.interactive = 'no';
        cfg.headshape.interactive = 'yes';
        cfg.coordsys              = 'neuromag';
        resliced   = ft_volumerealign(cfg, resliced);
        
    end
    
    mri_aligned = cell(1,length(AdptShape));
    hdm = mri_aligned;
    ind_grid = mri_aligned;
    for blk = 1:length(AdptShape)
        
        % make automatic coregistration based on headshape
        cfg=[];
        cfg.method                = 'headshape';
        %cfg.inputfile             = [PATHINMRI,filename];
        cfg.headshape             = AdptShape{blk};
        cfg.viewresult            = 'no';
        cfg.headshape.icp         = 'yes';
        
        cfg.coordsys              = 'neuromag';
        mri_aligned{blk}   = ft_volumerealign(cfg, resliced);
        
        scalpSeg.transform = mri_aligned{blk}.transform;
        brainSeg.transform = mri_aligned{blk}.transform;
        
        cfg = [];
        cfg.method = 'singleshell';
        cfg.tissue = 'scalp';
        cfg.numvertices = 10000;
        hdmScalpReAl = ft_prepare_headmodel(cfg,scalpSeg);
        
        hdmScalpReAl = ft_convert_units(hdmScalpReAl, 'mm');
        
        
        %subplot(3,2,2);
        figure(resFig);
        subplot(3,7,blk+7, 'replace');
        ft_plot_mesh(AdptShape{blk});
        ft_plot_mesh(AdptShape{blk}.fid.pos, 'vertexcolor', 'r', 'vertexsize', 20);
        ft_plot_mesh(hdmScalpReAl.bnd.pos, 'vertexsize', 1); axis tight
        %ft_plot_sens(sens, 'coil', 1, 'style', 'ko', 'coildiameter', 10);
        view([-79 14]);
        drawnow;
        %
        
        cfg = [];
        cfg.method = 'singleshell';
        cfg.tissue = 'brain';
        cfg.numvertices = 20000;
        hdm{blk} = ft_prepare_headmodel(cfg,brainSeg);
        
        hdm{blk} = ft_convert_units(hdm{blk}, 'mm');
        
        resliced = ft_convert_units(resliced, 'mm');
        
        cfg = [];
        cfg.coordsys = 'neuromag';
        cfg.grid.warpmni = 'yes';
        cfg.grid.nonlinear = 'yes';
        cfg.grid.template = template_grid;
        %cfg.grid.resolution = 6;
        cfg.mri = mri_aligned{blk};
        
        ind_grid{blk} = ft_prepare_sourcemodel(cfg);
        
        hdm{blk} = ft_convert_units(hdm{blk}, 'cm');
        hdmScalpReAl = ft_convert_units(hdmScalpReAl, 'cm');
        
        sensCM = ft_convert_units(sens, 'cm');
        
        figure(resFig);
        subplot(3,7,blk+14, 'replace');
        ft_plot_mesh(hdm{blk}.bnd.pos,'vertexcolor', 'b', 'vertexsize', 0.01); axis tight;
        ft_plot_mesh(hdmScalpReAl.bnd.pos, 'vertexsize', 0.5, 'vertexcolor', [0.5 0.5 0.5]); axis tight;
        ft_plot_mesh(ind_grid{blk}.pos(ind_grid{blk}.inside,:), 'vertexcolor', 'r', 'vertexsize', 5);
        ft_plot_sens(sensCM, 'coil', 1, 'style', 'ko', 'coildiameter', 1);
        view([267 -5]);
        
    end
    
    
    
    set(gcf, 'Position', get(0,'screensize'));
    
    
    saveas(gcf, [PATHOUT, 'VP_', SUBJ{sbj}, 'coregFull.png'], 'png');
    
    filename = ['tm', SUBJ{sbj}, '_hdm.mat'];
    save([PATHOUT, filename], 'brainSeg', 'scalpSeg', 'hdm', 'resliced', 'ind_grid');    
    
    close all;
end

disp('Dipoles inside:');
disp(insideDipoles);