clear;
close all;
clc;

MAINPATH    = '/data3/Florian/tMentRotNew/analysis/';
PATHINMEG = [MAINPATH, 'resampled/'];
PATHINFILT = [MAINPATH, 'lcmv/'];
PATHOUT = [MAINPATH, 'artStrength/'];
mkdir(PATHOUT);

SUBJ = {'01', '02', '03', '04', '05', '06', '07', '08', '09', '10', '11', '12', '13', '14', '15', '16', '17', '18', '19', '20', '21', '22', '23', '24', '25'};
EXCL = {'01', '10', '16', '24', '25'};

addpath('/data3/Florian/fieldtrip/');
ft_defaults;

ArtfctRatioSens = zeros(10,2,304);
ArtfctRatioSource = zeros(10,2,889);
ArtfctRatio = zeros(10,8);
idxSbj = 1;
tic;

h = waitbar(0, 'initializing');

for sbj = 1:length(SUBJ)
    
    h = waitbar(sbj/length(SUBJ), h, ['processing SUBJ: ', SUBJ{sbj}]);
    
    PATHINRAW = [MAINPATH, 'rawdir/tm', SUBJ{sbj}, 'a/'];
    filename = ['VP_', SUBJ{sbj}, '.mat'];
    
    load([PATHINRAW, filename]);
    
    if strcmp(BEHAV.condition, 'c')
        continue;
    elseif ismember(SUBJ{sbj}, EXCL)
        continue;
    end
    
    filename = ['tm_', SUBJ{sbj}, '_rs.mat'];
    
    load([PATHINMEG, filename]);
    
    filename = ['tm_', SUBJ{sbj}, '_filters.mat'];
    
    load([PATHINFILT, filename]);
    %% segment MEG data
    
    idx100 = find([EVENTS.value] == 100);
    
    cfg = [];
    cfg.trl(:,1) = [EVENTS(idx100).sample]-5*data.fsample;
    cfg.trl(:,2) = [EVENTS(idx100).sample]+7*data.fsample-1;
    cfg.trl(:,3) = 0;
    
    data = ft_redefinetrial(cfg,data);
    
    cfg = [];
    cfg.offset = -5*data.fsample;
    
    data = ft_redefinetrial(cfg,data);
    
    idxBlkEnd = 1:48:length(data.trial);
    idxBlkStart = idxBlkEnd;
    idxBlkStart(2) = idxBlkStart(2)+3;
    
    MEG = cell(1,6);
    
    parfor blk = 1:6
        
        idxBlk = blk - 3;
        
        if blk < 4
            
            cfg = [];
            cfg.channel = 'MEG';
            cfg.trials = idxBlkStart(blk):idxBlkEnd(blk)+47;
            datatemp = ft_selectdata(cfg,data);
            
            MEG{blk} = datatemp;
            
            cfg = [];
            cfg.method = 'wavelet';
            cfg.output = 'pow';
            %cfg.taper = 'hanning';
            cfg.pad = 14;
            cfg.padtype = 'zero';
            cfg.keeptrials = 'no';
            cfg.foi = 1:0.5:30;
            %cfg.t_ftimwin = ones(1,length(cfg.foi))*1;
            cfg.toi = -3:0.04:6.996;
            cfg.width = 7;
            cfg.gwidth = 3;
            
            MEG{blk} = ft_freqanalysis(cfg,MEG{blk});
            
        elseif blk > 3
            
            %% apply spatial filter
            
            cfg = [];
            cfg.channel = 'MEG';
            cfg.trials = idxBlkStart(idxBlk):idxBlkEnd(idxBlk)+47;
            datatemp = ft_selectdata(cfg,data);
            
            MEG{blk} = datatemp;
            
            nrpt = length(datatemp.trial);
            
            fprintf(['using precomputed filters \n']);
            ft_progress('init', 'text');
            
            for i = 1:length(datatemp.trial)
                
                ft_progress(i/nrpt, 'scanning repetition %d of %d', i,nrpt);
                
                MEG{blk}.trial{i} = beamfilts{idxBlk}*datatemp.trial{i};
                
            end
            
            ft_progress('close');
            
            MEG{blk}.label = cellstr(num2str([1:size(beamfilts{idxBlk},1)]'));
            
            MEG{blk}=rmfield(MEG{blk}, 'cfg');
            MEG{blk}=rmfield(MEG{blk}, 'grad');
            
            
            cfg = [];
            cfg.method = 'wavelet';
            cfg.output = 'pow';
            %cfg.taper = 'hanning';
            cfg.pad = 14;
            cfg.padtype = 'zero';
            cfg.keeptrials = 'no';
            cfg.foi = 1:0.5:30;
            %cfg.t_ftimwin = ones(1,length(cfg.foi))*1;
            cfg.toi = -3:0.04:6.996;
            cfg.width = 7;
            cfg.gwidth = 3;
            
            MEG{blk} = ft_freqanalysis(cfg,MEG{blk});
            
        end
        
    end
    
    save([PATHOUT, 'SUBJ_', SUBJ{sbj}, 'artStrength.mat'], 'MEG');
    
    toi = [0 2];
    toi = nearest(MEG{1}.time, toi);
    foi = [BEHAV.frequency-2 BEHAV.frequency+2];
    foi = nearest(MEG{1}.freq,foi);
    
    ArtfctRatioSens(idxSbj,1,:) = mean(mean(MEG{2}.powspctrm(:,foi,toi),3),2) ./ mean(mean(MEG{1}.powspctrm(:,foi,toi),3),2);
    ArtfctRatioSens(idxSbj,2,:) = mean(mean(MEG{3}.powspctrm(:,foi,toi),3),2) ./ mean(mean(MEG{1}.powspctrm(:,foi,toi),3),2);
    ArtfctRatio(idxSbj,1) = mean(ArtfctRatioSens(idxSbj,1,:));
    ArtfctRatio(idxSbj,2) = mean(ArtfctRatioSens(idxSbj,2,:));
    
    ArtfctRatio(idxSbj,5) = max(ArtfctRatioSens(idxSbj,1,:));
    ArtfctRatio(idxSbj,6) = max(ArtfctRatioSens(idxSbj,2,:));
    
    ArtfctRatioSource(idxSbj,1,:) = mean(mean(MEG{5}.powspctrm(:,foi,toi),3),2) ./ mean(mean(MEG{4}.powspctrm(:,foi,toi),3),2);
    ArtfctRatioSource(idxSbj,2,:) = mean(mean(MEG{6}.powspctrm(:,foi,toi),3),2) ./ mean(mean(MEG{4}.powspctrm(:,foi,toi),3),2);
    ArtfctRatio(idxSbj,3) = mean(ArtfctRatioSource(idxSbj,1,:));
    ArtfctRatio(idxSbj,4) = mean(ArtfctRatioSource(idxSbj,2,:));
    
    ArtfctRatio(idxSbj,7) = max(ArtfctRatioSource(idxSbj,1,:));
    ArtfctRatio(idxSbj,8) = max(ArtfctRatioSource(idxSbj,2,:));
    
    idxSbj = idxSbj + 1;
    
end

load mni_grid_1_5_cm_889pnts.mat;
load standard_mri.mat;

artRatioFig = figure;

for blk = 1:2
    
    source = template_grid;
    source.pow = NaN(length(source.inside),1);
    source.pow(source.inside) = mean(ArtfctRatioSource(:,blk,:),1);
    
    cfg = [];
    cfg.parameter = 'pow';
    scr_int = ft_sourceinterpolate(cfg,source,mri);
    scr_int.mask = scr_int.pow;
    
    cfg = [];
    cfg.funparameter = 'pow';
    cfg.method = 'surface';
    %cfg.method = 'slice';
    %cfg.maskparameter = 'mask';
    cfg.funcolormap = jet;
    cfg.camlight = 'no';
    cfg.downsample = 1;
    cfg.nslices = 9;
    cfg.surfinflated = 'surface_inflated_both_caret.mat';
    cfg.opacitymap = 'rampup';
    cfg.opacitylim = [2 10];
    cfg.funcolorlim = [0 10];
    
    ft_sourceplot(cfg,scr_int); axis tight;
    view([-56 16]);
    
    h = gcf;
    hax1 = gca;
    figure(artRatioFig);
    s1 = subplot(2,1,blk);
    pos = get(s1,'Position');
    delete(s1);
    hax2 = copyobj(hax1,artRatioFig);
    set(hax2, 'Position', pos);
    set(artRatioFig, 'colormap', jet);
    drawnow;
    close(h);
    
end

c1 = colorbar;
c1.Label.String = 'Alpha Power Artifact Ratio';
c1.Position = [0.8, 0.1, 0.05, 0.8];
c1.FontSize = 14;

save([PATHOUT, 'AVGartRatio.mat'], 'ArtfctRatio', 'ArtfctRatioSens', 'ArtfctRatioSource');