clear;
close all;
clc;

%% Import .fif files, concettinate, filter and resample data

MAINPATH = '/data3/Florian/tMentRotNew/analysis/';
PATHOUT = [MAINPATH, 'resampled/'];
mkdir(PATHOUT);

addpath('/data3/Florian/fieldtrip/');

ft_defaults;

SUBJ = {'01', '02', '03', '04', '05', '06', '07', '08', '09', '10', '11', '12', '13', '14', '15', '16', '17', '18', '19', '20', '21', '22', '23', '24', '25'};
%SUBJ = {'25'};
%SUBJ = {'01', '02', '03', '04', '05', '06', '07', '08', '09', '10', '11', '12', '13', '14', '15', '16', '17'};

h = waitbar(0, 'start resampling');

for sbj = 1:length(SUBJ)
    
    h = waitbar(sbj/length(SUBJ), h, ['resampling subj:', SUBJ{sbj}]);
    
    %% load datasets
    PATHIN = [MAINPATH, 'rawdir/tm', SUBJ{sbj}, 'a/'];
    PATHINMove = [MAINPATH, 'movementEst/tm', SUBJ{sbj}, 'a/'];
    filename = ['tm', SUBJ{sbj},'a2.fif'];
    filenameMove = ['tm', SUBJ{sbj}, 'a2_quart.fif'];
    
    EVENTS = cell(1,3);
    MEG = cell(1,3);
    MOVE = cell(1,3);
    
    cfg = [];
    cfg.dataset = [PATHIN,filename];
    
    MEG{1} = ft_preprocessing(cfg);
    EVENTS{1} = ft_read_event(cfg.dataset);    
    
    filename = ['tm', SUBJ{sbj},'a2-1.fif'];
    cfg.dataset = [PATHIN,filename];
    
    MEG{2} = ft_preprocessing(cfg);
    EVENTS{2} = ft_read_event(cfg.dataset);
    
    filename = ['tm', SUBJ{sbj},'a2-2.fif'];
    cfg.dataset = [PATHIN,filename];
    
    MEG{3} = ft_preprocessing(cfg);
    EVENTS{3} = ft_read_event(cfg.dataset);
    
    cfg = [];
    cfg.dataset = [PATHINMove, filenameMove];
    
    MOVE{1} = ft_preprocessing(cfg);
    
    filenameMove = ['tm', SUBJ{sbj}, 'a2-1_quart.fif'];
    cfg.dataset = [PATHINMove, filenameMove];
    
    MOVE{2} = ft_preprocessing(cfg);
    
    filenameMove = ['tm', SUBJ{sbj}, 'a2-2_quart.fif'];
    cfg.dataset = [PATHINMove, filenameMove];
    
    MOVE{3} = ft_preprocessing(cfg);
    
    cfg = [];
    cfg.channel = 'QUAT*';
    
    MOVE = cellfun(@(x) ft_selectdata(cfg,x), MOVE, 'UniformOutput', 0);
    
    cfg = [];
    
    MEG = cellfun(@(x,y) ft_appenddata(cfg,x,y), MEG,MOVE, 'UniformOutput', 0);
    
    clear MOVE;
    %% merge data
    
    data = MEG{1};
    
    data.trial{1} = [MEG{1}.trial{1}, MEG{2}.trial{1}, MEG{3}.trial{1}];
    data.sampleinfo(2) = length(data.trial{1});
    
    data.time{1} = 0:1/data.fsample:(length(data.trial{1})/data.fsample)-1/data.fsample;
    
    for i = 1:length(EVENTS{2})
    
        EVENTS{2}(i).sample = EVENTS{2}(i).sample + MEG{1}.sampleinfo(2);
    
    end
    
    for i = 1:length(EVENTS{3})
        
        EVENTS{3}(i).sample = EVENTS{3}(i).sample + MEG{1}.sampleinfo(2) + MEG{2}.sampleinfo(2);
    
    end
    
    EVENTS = [EVENTS{1}; EVENTS{2}; EVENTS{3}];
    
    clear MEG
    
    %% resample to 250 Hz
    
    cfg = [];
    cfg.resamplefs = 250;
    
    data = ft_resampledata(cfg,data);
    
    for i = 1:length(EVENTS)
        EVENTS(i).sample = ceil(EVENTS(i).sample/4);
    end
    
    %% check and correct event markers
    idx = [EVENTS.value] == 4096+12;
    if sum(idx) > 0
        for i = find(idx)
        EVENTS(i).value = 12;
        end
    end
    
    idx = [EVENTS.value] == 4096+100;
    if sum(idx) > 0
        for i = find(idx)
        EVENTS(i).value = 100;
        end
    end
    
    idx = [EVENTS.value] == 8192+12;
    if sum(idx) > 0
        for i = find(idx)
        EVENTS(i).value = 12;
        end
    end
    
    idx = [EVENTS.value] == 8192+100;
    if sum(idx) > 0
        for i = find(idx)
        EVENTS(i).value = 100;
        end
    end
    
    idx = [EVENTS.value] == 2048+12;
    if sum(idx) > 0
        for i = find(idx)
        EVENTS(i).value = 12;
        end
    end
    
     idx = [EVENTS.value] == 2048+60;
    if sum(idx) > 0
        for i = find(idx)
        EVENTS(i).value = 60;
        end
    end
    
    idx = [EVENTS.value] == 2048+72;
    if sum(idx) > 0
        for i = find(idx)
        EVENTS(i).value = 72;
        end
    end
    
    idx = [EVENTS.value] == 12;
    for i = find(idx);
        if EVENTS(i).value == EVENTS(i+1).value 
            EVENTS(i+1).value = 999;
        end        
    end
    
    cfg = [];
    cfg.channel = 'QUAT*';
    
    temp = ft_selectdata(cfg,data);
    
    %% filter
    cfg = [];
    cfg.channel = {'all' '-QUAT*'};
    cfg.lpfilter = 'yes';
    cfg.lpfreq = 40;
    cfg.hpfilter = 'yes';
    cfg.hpfreq = 1;
    
    data = ft_preprocessing(cfg,data);
    
    data = ft_appenddata([],data,temp);
    
    %% remove static bad channels
    cfg = [];
    cfg.channel = {'all', '-MEG0243', '-MEG2411'};
    
    data = ft_selectdata(cfg,data);
    
    filename = ['tm_' SUBJ{sbj}, '_rs.mat'];
    
    save([PATHOUT, filename], 'data', 'EVENTS', '-v7.3');
    
    
end

delete(h);