clear;
close all;
clc;

h = waitbar(0, 'initialize..');
poolObj = parpool(7);

MAINPATH = '/data3/Florian/tMentRotNew/analysis/';

PATHINMEG = [MAINPATH, 'resampled/'];
PATHINMRI = [MAINPATH, 'mri/'];
PATHOUT = [MAINPATH, 'lcmv/'];

mkdir(PATHOUT);
addpath('/data3/Florian/fieldtrip');
ft_defaults;

SUBJ = {'01', '02', '03', '04', '05', '06', '07', '08', '09', '10', '11', '12', '13', '14', '15', '16', '17', '18', '19', '20', '21', '22', '23', '24', '25'};
%SUBJ = {'03', '10', '13', '18', '20', '21'};

for sbj = 1:length(SUBJ)
    h = waitbar(sbj/length(SUBJ),h, ['SUBJ: ', SUBJ{sbj}]);
    %TFRfig = figure;
    
    %% load data
    
    filename = ['tm_', SUBJ{sbj}, '_rs.mat'];
    
    data = load([PATHINMEG, filename]);
    EVENTS = data.EVENTS;
    data = data.data;
    
    
    %% divide data into 10 min blocks
    idxTRL = [EVENTS.value] == 12;
    
    idxTRL = find(idxTRL);
    
    idxBlk = 1:48:length(idxTRL);
    
    idxTRLEnd = idxTRL(idxBlk);
    idxBlk(2) = idxBlk(2)+3;
    idxTRLStart = idxTRL(idxBlk);
    
    cfg = [];
    
    cfg.trl(:,1) = [EVENTS(idxTRLStart).sample];
    cfg.trl(:,2) = [EVENTS(idxTRLEnd).sample]+600*data.fsample-1;
    cfg.trl(:,3) = 0;
    
    cfg.trl(3,2) = cfg.trl(3,2) - 12*data.fsample;
    
    data = ft_redefinetrial(cfg,data);
    
    filename = ['tm', SUBJ{sbj}, '_hdm.mat'];
    load([PATHINMRI, filename]);
    
    %% Correct tra matrix
    [~, grd_idx] = setdiff(data.grad.label, ft_channelselection('MEG*1', data.grad.label));
    
    tmp = data.grad.tra(grd_idx,:);
    checktra = sum(ismember(unique(tmp(:)), [1 -1]));
    
    if checktra == 2;
        disp('Correcting tra matrix');
        data.grad.tra(grd_idx,:) = data.grad.tra(grd_idx,:)/0.017;
    else
        
        disp('The tra matrix to be adjusted or is wrong');
        
    end
    
    
    MEG = cell(1,7);
    beamfilts = MEG;
    noiseEst = beamfilts;
    lf = beamfilts;
    tic
    
    
    parfor blk = 1:7
        
        %% compute leadfield matrix
        cfg = [];
        cfg.headmodel = hdm{blk};
        cfg.channel = 'MEG';
        cfg.grid = ind_grid{blk};
        cfg.grad = data.grad;
        cfg.normalize = 'yes';
        
        lf{blk} = ft_prepare_leadfield(cfg,data);
        
        %% segment data in each block into 2sec segments
        cfg = [];
        cfg.trials = blk;        
        cfg.length = 2;
        cfg.overlap = 0;
        
        MEG{blk} = ft_redefinetrial(cfg,data);
        
        for i = 1:length(MEG{blk}.time)
            
            MEG{blk}.time{i} = MEG{blk}.time{1};
            
        end
        
        %% compute co-variance
        cfg = [];
        cfg.channel = 'MEG';
        %cfg.trials = idxBlk(blk):idxBlk(blk)+47;
        cfg.covariance = 'yes';
        cfg.covariancewindow = 'all';
        cfg.vartrllength = 0;
        
        dataAvg = ft_timelockanalysis(cfg, MEG{blk});
        
        %% compute filters for each block
        cfg = [];
        cfg.method = 'lcmv';
        cfg.grid = lf{blk};
        cfg.headmodel = hdm{blk};
        cfg.lcmv.keepfilter = 'yes';
        cfg.lcmv.fixedori = 'yes';
        cfg.lcmv.lambda = [];
        cfg.lcmv.projectnoise = 'yes';
        
        lcmvall = ft_sourceanalysis(cfg,dataAvg);
        
        beamfilts{blk} = cat(1,lcmvall.avg.filter{:});
        noiseEst{blk} = lcmvall.avg.noise;
        
    end
    toc
    save([PATHOUT, 'tm_' SUBJ{sbj}, '_filters.mat'], 'beamfilts', 'lf', 'noiseEst', '-v7.3');
end

delete(h);

