clear;
close all;
clc;

%% Project MEG data into source space and perform TF-analysis on virtual sensors...

doPlot = 1;

MAINPATH = '/data3/Florian/tMentRotNew/analysis/';
PATHINMEG = [MAINPATH, 'resampled/'];
PATHINFILT = [MAINPATH, 'lcmv/'];
PATHOUT = [MAINPATH, 'TFR/'];
mkdir(PATHOUT);

addpath('/data3/Florian/fieldtrip/');
ft_defaults;

SUBJ = {'01', '02', '03', '04', '05', '06', '07', '08', '09', '10', '11', '12', '13', '14', '15', '16', '17', '18', '19', '20', '21', '22', '23', '24', '25'};
%SUBJ = {'03', '10', '13', '18', '20', '21'};
hw = waitbar(0,'initializing analysis...');
poolObj = parpool(7);

try

for sbj = 1:length(SUBJ)
    
    tic;
    
    if sbj == 1
        hw = waitbar(sbj/length(SUBJ), hw, ['SUBJ: ', SUBJ{sbj}]);
    end
    
    if doPlot == 1;
        resFig = figure;
    end
    %% load data and beamformer filters
    
    filename = ['tm_', SUBJ{sbj}, '_rs.mat'];
    
    load([PATHINMEG, filename]);
    
    PATHINRAW = [MAINPATH, 'rawdir/tm', SUBJ{sbj}, 'a/'];
    filename = ['VP_', SUBJ{sbj}, '.mat'];
    
    load([PATHINRAW, filename]);
    
    filename = ['tm_', SUBJ{sbj}, '_filters.mat'];
    
    load([PATHINFILT, filename]);
    
    %% segment MEG data around Mental rotation stimui
    
    idx100 = find([EVENTS.value] == 100);
    
    cfg = [];
    cfg.trl(:,1) = [EVENTS(idx100).sample]-5*data.fsample;
    cfg.trl(:,2) = [EVENTS(idx100).sample]+7*data.fsample-1;
    cfg.trl(:,3) = 0;
    
    data = ft_redefinetrial(cfg,data);
    
    cfg = [];
    cfg.offset = -5*data.fsample;
    
    data = ft_redefinetrial(cfg,data);
    
    %% asign trials to blocks
    idxBlkEnd = 1:48:length(data.trial);
    idxBlkStart = idxBlkEnd;
    % leave out trials during fade in and out
    idxBlkStart(2) = idxBlkStart(2)+3;
    
    MEG = cell(1,length(idxBlkStart));
    
    load standard_mri.mat;
    load mni_grid_1_5_cm_889pnts.mat;
    
    meanNoise = mean([noiseEst{:}],2);
    parfor blk = 1:length(idxBlkStart)
        
        %% apply spatial filter
        
        cfg = [];
        cfg.channel = 'MEG';
        cfg.trials = idxBlkStart(blk):idxBlkEnd(blk)+47;
        datatemp = ft_selectdata(cfg,data);
        
        MEG{blk} = datatemp;
        
        nrpt = length(datatemp.trial);
        
        fprintf(['using precomputed filters \n']);
        ft_progress('init', 'text');
        
        for i = 1:length(datatemp.trial)
            
            ft_progress(i/nrpt, 'scanning repetition %d of %d', i,nrpt);
          
            MEG{blk}.trial{i} = beamfilts{blk}*datatemp.trial{i}; 
            
        end
        
        ft_progress('close');
        
        MEG{blk}.label = cellstr(num2str([1:size(beamfilts{blk},1)]'));
        
        MEG{blk}=rmfield(MEG{blk}, 'cfg');
        MEG{blk}=rmfield(MEG{blk}, 'grad');
        
        %% add artificial channel with stimulation signal
        
        signal = 1e-12*sin(2*pi*MEG{blk}.time{1}*BEHAV.frequency);
        
        MEG{blk}.trial = cellfun(@(x) [x; signal], MEG{blk}.trial, 'UniformOutput', 0);
        
        MEG{blk}.label{end+1} = 'sine';
        
        %% perform wavelet analysis;
        cfg = [];
        cfg.method = 'wavelet';
        cfg.output = 'pow';
        %cfg.taper = 'hanning';
        cfg.pad = 14;
        cfg.padtype = 'zero';
        cfg.keeptrials = 'no';
        cfg.foi = 1:0.5:30;
        cfg.toi = -3:0.04:6.996;
        cfg.width = 7;
        cfg.gwidth = 3;
        
        MEG{blk} = ft_freqanalysis(cfg,MEG{blk});
        
    end
    
    if doPlot == 1
        for blk = 1:length(MEG)
            %% Plotting
            
            cfg = [];
            cfg.channel = {'all', '-sine'};
            %cfg.baseline = [-3, 0];
            %cfg.baselinetype = 'relchange';
            %cfg.zlim = [-0.5, 0.5];
            cfg.colormap = jet;
            cfg.xlim = [-5 20];
            cfg.colorbar = 'no';
            figure(resFig);
            subplot(4,7,blk);
            ft_singleplotTFR(cfg,MEG{blk});
            title(['SUBJ ', SUBJ{sbj}, ' Block', num2str(blk)]);
            %% create sourceplot
            
            foi = [BEHAV.frequency-2 BEHAV.frequency+2];
            foi = nearest(MEG{blk}.freq,foi);
            toiRef = [-2.5 0];
            toiRef = nearest(MEG{blk}.time,toiRef);
            toiRef(2) = toiRef(2) - 1;
            toiTest = [0 3];
            toiTest = nearest(MEG{blk}.time,toiTest);
            toiTest(2) = toiTest(2) - 1;
            
            refPow = mean(mean(MEG{blk}.powspctrm(1:end-1,foi(1):foi(2), toiRef(1):toiRef(2)),3),2);
            %testPow = mean(mean(MEG{blk}.powspctrm(1:end-1,foi(1):foi(2), toiTest(1):toiTest(2)),3),2);
            
            source = template_grid;
            source.pow = NaN(length(source.inside),1);
            
            if ismember(blk, [1 4 5 6 7])
                source.pow(source.inside) = refPow./ meanNoise(source.inside);
            elseif ismember(blk, [2 3])
                source.pow(source.inside) = refPow./ meanNoise(source.inside);
            end
            
            cfg = [];
            cfg.parameter = 'pow';
            scr_int = ft_sourceinterpolate(cfg,source,mri);
            
            scr_int.mask = abs(scr_int.pow);
            
            cfg = [];
            cfg.funparameter = 'pow';
            %cfg.method = 'surface';
            cfg.method = 'slice';
            cfg.maskparameter = 'mask';
            cfg.funcolormap = jet;
            cfg.camlight = 'no';
            cfg.downsample = 1;
            cfg.nslices = 9;
                    
        
            ft_sourceplot(cfg,scr_int); axis tight;
            %view([-56 16]);
            h = gcf;
            hax1 = gca;
            figure(resFig);
            s1 = subplot(4,7,blk+7);
            pos = get(s1,'Position');
            delete(s1);
            hax2 = copyobj(hax1,resFig);
            set(hax2, 'Position', pos);
            set(resFig, 'colormap', jet);
            drawnow;
            close(h);
            
            cfg = [];
            cfg.channel = {'all', '-sine'};
            cfg.baseline = [-3, 0];
            cfg.baselinetype = 'absolute';
            %cfg.zlim = [-0.5, 0.5]*10e-24;
            cfg.zlim = 'maxabs';
            cfg.colormap = jet;
            cfg.colorbar = 'no';
            cfg.xlim = [-5 6];
            figure(resFig);
            subplot(4,7,blk+14);
            ft_singleplotTFR(cfg,MEG{blk});
            title('');
            
            foi = [BEHAV.frequency-2 BEHAV.frequency+2];
            foi = nearest(MEG{blk}.freq,foi);
            toiRef = [-2.5 0];
            toiRef = nearest(MEG{blk}.time,toiRef);
            toiRef(2) = toiRef(2) - 1;
            toiTest = [0 3];
            toiTest = nearest(MEG{blk}.time,toiTest);
            toiTest(2) = toiTest(2) - 1;
            
            refPow = mean(mean(MEG{blk}.powspctrm(1:end-1,foi(1):foi(2), toiRef(1):toiRef(2)),3),2);
            testPow = mean(mean(MEG{blk}.powspctrm(1:end-1,foi(1):foi(2), toiTest(1):toiTest(2)),3),2);
            
            source = template_grid;
            source.pow = NaN(length(source.inside),1);
            
            source.pow(source.inside) = testPow-refPow;% ./ refPow) * 100;
            
            cfg = [];
            cfg.parameter = 'pow';
            scr_int = ft_sourceinterpolate(cfg,source,mri);
            
            scr_int.mask = abs(scr_int.pow);
            
            cfg = [];
            cfg.funparameter = 'pow';
            %cfg.method = 'surface';
            cfg.method = 'slice';
            cfg.nslices = 9;
            cfg.maskparameter = 'mask';
            cfg.funcolormap = jet;
            cfg.camlight = 'no';
            cfg.downsample = 1;
            cfg.funcolorlim = 'maxabs';
            
            
            ft_sourceplot(cfg,scr_int);
            %view([-56 16]);
            h = gcf;
            hax1 = gca;
            figure(resFig);
            s1 = subplot(4,7,blk+21);
            pos = get(s1,'Position');
            delete(s1);
            hax2 = copyobj(hax1,resFig);
            set(hax2, 'Position', pos);
            set(resFig, 'colormap', jet);
            drawnow;
            close(h);
        end
    end
    
    if doPlot == 1;
        set(resFig, 'position', get(0,'screensize'))
        saveas(resFig, [PATHOUT, 'Subject', SUBJ{sbj}, '_TFR.png'], 'png');
        close(resFig);
    end
    
    save([PATHOUT, 'tm_', SUBJ{sbj}, '_lcmvTFR.mat'], 'MEG', 'BEHAV', '-v7.3');
    
    t = toc;
    
    remSubj = length(SUBJ) - sbj;
    
    remTime = remSubj * t;
    
    remH = num2str(floor(remTime/3600));
    remM = num2str(ceil((floor(rem(remTime,3600))/60)));
    
    if strcmp(SUBJ{sbj},SUBJ{end})
        
        delete(hw);
        delete(poolObj);
    else
        
        hw = waitbar(sbj/length(SUBJ), hw, ['SUBJ: ', SUBJ{sbj+1}, ' remaining time: ', remH, 'h ', remM, ' min']);
        
    end
end

catch ME
     delete(hw);
     delete(poolObj);
     error(getReport(ME, 'extended'));
end
    
