clear;
close all;
clc;

doPlot = 1;
doSave = 1;

MAINPATH    = '/data3/Florian/tMentRotNew/analysis/';
PATHIN      = [MAINPATH, 'TFR/'];
PATHINFILT  = [MAINPATH, 'lcmv/'];
PATHOUT     = [MAINPATH, 'AVG/'];

mkdir(PATHOUT);
addpath('/data3/Florian/fieldtrip/');
ft_defaults;

SUBJ = {'01', '02', '03', '04', '05', '06', '07', '08', '09', '10', '11', '12', '13', '14', '15', '16', '17', '18', '19', '20', '21', '22', '23', '24', '25'};
EXCL = {'01', '10', '16', '24', '25'};

%SUBJ = setdiff(SUBJ, EXCL);

data = cell(length(SUBJ), 7);
normMEG = data;
relData = data;
sources = data;
normSources = sources;
sourcesRef = sources;
sourcesTest = sources;
idxStim = zeros(1,length(SUBJ));
idxSham = idxStim;
idxExcl = idxStim;

load standard_mri.mat;
load mni_grid_1_5_cm_889pnts.mat


for sbj = 1:length(SUBJ)
    
    sources(sbj,:) = {template_grid};
    disp(['loading Subject', SUBJ{sbj}])
    
    %% load data
    filename = ['tm_', SUBJ{sbj}, '_lcmvTFR.mat'];
    load([PATHIN, filename]);
    
    filename = ['tm_', SUBJ{sbj}, '_filters.mat'];
    load([PATHINFILT, filename]);
    
    
    if ismember(SUBJ{sbj}, EXCL)
        
        idxExcl(sbj) = 1;
        
    else
        
        switch BEHAV.condition
            case 's'
                idxStim(sbj) = 1;
            case 'c'
                idxSham(sbj) = 1;
        end
        
    end
    
    %% align spectra on IAF
    offset = 10-BEHAV.frequency;
    foi = [BEHAV.frequency - 7 BEHAV.frequency + 18];
    
    for blk = 1:length(MEG)
        
        cfg = [];
        cfg.channel = {'all', '-sine'};
        cfg.frequency = foi;
        
        MEG{blk} = ft_selectdata(cfg,MEG{blk});
        
        MEG{blk}.freq = MEG{blk}.freq + offset;
        
        sources{sbj,blk}.pow = NaN(length(sources{sbj,blk}.inside),1);
        normSources{sbj,blk} = sources{sbj,blk};
        sourcesRef{sbj,blk} = sources{sbj,blk};
        sourcesTest{sbj,blk} = sources{sbj,blk};
        
        % extract power within IAF band
        
        foi_scr = [8 12];
        foi_scr = nearest(MEG{blk}.freq,foi_scr);
        toiRef = [-2.5 -0.5];
        toiRef = nearest(MEG{blk}.time,toiRef);
        toiRef(2) = toiRef(2)-1;
        toiTest = [0 2];
        toiTest = nearest(MEG{blk}.time,toiTest);
        toiTest(2) = toiTest(2) - 1;
        
        refPow =  mean(mean(MEG{blk}.powspctrm(:,foi_scr(1):foi_scr(2), toiRef(1):toiRef(2)),3),2);
        testPow = mean(mean(MEG{blk}.powspctrm(:,foi_scr(1):foi_scr(2), toiTest(1):toiTest(2)),3),2);
        
        % compute power difference for each virtual channel
        sources{sbj,blk}.pow(sources{sbj,blk}.inside) = ((refPow - testPow));% ./ refPow) * 100;
        
        % get power pre and post stimulus
        sourcesRef{sbj,blk}.pow(sourcesRef{sbj,blk}.inside) = refPow;
        sourcesTest{sbj,blk}.pow(sourcesTest{sbj,blk}.inside) = testPow;
        
        % baseline correct TFR spectrum
        cfg = [];
        cfg.baseline = [-2.5 -0.5];
        cfg.baselinetype = 'absolute';
        cfg.parameter = 'powspctrm';
        
        relMEG{blk} = ft_freqbaseline(cfg,MEG{blk});
        
        refPowSpctrm(:,:,sbj,blk) = mean(MEG{blk}.powspctrm(:,:, toiRef(1):toiRef(2)),3);
        tstPowSpctrm(:,:,sbj,blk) = mean(MEG{blk}.powspctrm(:,:, toiTest(1):toiTest(2)),3);
        
    end
    
    data(sbj,:) = MEG;
    relData(sbj,:) = relMEG;
    
end

clear MEG;

load standard_mri.mat;
load mni_grid_1_5_cm_889pnts.mat;

idxStim = find(idxStim);
idxSham = find(idxSham);
idxExcl = find(idxExcl);

Avg_scr = cell(2,7);
Avg_int = cell(2,7);
Avg_tfr = cell(2,7);
relAvg_tfr = cell(2,7);

if doPlot == 1;
    Avg_fig = figure;
end
for blk = 1:7
    
    %% Average Source-level power difference
    cfg = [];
    cfg.parameter = 'pow';
    cfg.keepindividual = 'no';
    
    Avg_scr{1,blk} = ft_sourcegrandaverage(cfg,sources{idxStim, blk});
    Avg_scr{2,blk} = ft_sourcegrandaverage(cfg,sources{idxSham, blk});
    
    %     Avg_scr{1,blk}.mask = zeros(1,length(Avg_scr{1,blk}.inside));
    %     Avg_scr{1,blk}.mask(idxRoi) = 1;
    %
    %     Avg_scr{2,blk}.mask = zeros(1,length(Avg_scr{2,blk}.inside));
    %     Avg_scr{2,blk}.mask(idxRoi) = 1;
    %
    cfg = [];
    cfg.parameter = {'pow'};
    Avg_int{1,blk} = ft_sourceinterpolate(cfg, Avg_scr{1,blk}, mri);
    Avg_int{2,blk} = ft_sourceinterpolate(cfg, Avg_scr{2,blk}, mri);
    
    Avg_int{1,blk}.mask = abs(Avg_int{1,blk}.pow);
    Avg_int{2,blk}.mask = abs(Avg_int{2,blk}.pow);
    
    %% Average virtual channel TFRs
    cfg = [];
    cfg.parameter = 'powspctrm';
    cfg.keepindividual = 'no';
    
    Avg_tfr{1,blk} = ft_freqgrandaverage(cfg,data{idxStim,blk});
    Avg_tfr{2,blk} = ft_freqgrandaverage(cfg,data{idxSham,blk});
    
    relAvg_tfr{1,blk} = ft_freqgrandaverage(cfg,relData{idxStim,blk});
    relAvg_tfr{2,blk} = ft_freqgrandaverage(cfg,relData{idxSham,blk});
    
    % plot average data
    if doPlot == 1
        
        cfg = [];
        cfg.parameter = 'powspctrm';
        cfg.colormap = jet;
        %cfg.baseline = [-2.5 0];
        %cfg.baselinetype = 'relchange';
        cfg.zlim = 'maxabs';
        cfg.xlim = [-3 6];
        cfg.colorbar = 'no';
        
        figure(Avg_fig);
        subplot(4,7,blk);
        ft_singleplotTFR(cfg,relAvg_tfr{1,blk}); hold on;
        plot([0 0], [3 28], 'w', 'LineWidth', 2);
        title(['Block ', num2str(blk)]);
        
        subplot(4,7,blk+14);
        ft_singleplotTFR(cfg,relAvg_tfr{2,blk}); hold on;
        plot([0 0], [3 28], 'w', 'LineWidth', 2);
        title(' ');
        
        cfg = [];
        cfg.funparameter = 'pow';
        cfg.method = 'slice';
        %cfg.method = 'surface';
        cfg.surfinflated = 'surface_inflated_both_caret.mat';
        cfg.nslices = 9;
        cfg.maskparameter = 'mask';
        cfg.funcolormap = jet;
        cfg.camlight = 'no';
        %cfg.downsample = 10;
        cfg.funcolorlim = 'maxabs';
        
        ft_sourceplot(cfg,Avg_int{1,blk});
        %view([-56 16]);
        h = gcf;
        hax1 = gca;
        figure(Avg_fig);
        s1 = subplot(4,7,blk+7);
        pos = get(s1,'Position');
        delete(s1);
        hax2 = copyobj(hax1,Avg_fig);
        set(hax2, 'Position', pos);
        set(Avg_fig, 'colormap', jet);
        drawnow;
        close(h);
        
        cfg = [];
        cfg.funparameter = 'pow';
        cfg.method = 'slice';
        cfg.nslices = 9;
        cfg.maskparameter = 'mask';
        cfg.funcolormap = jet;
        cfg.camlight = 'no';
        %cfg.downsample = 10;
        cfg.funcolorlim = 'maxabs';
        
        ft_sourceplot(cfg,Avg_int{2,blk});
        %view([-56 16]);
        
        h = gcf;
        hax1 = gca;
        figure(Avg_fig);
        s1 = subplot(4,7,blk+21);
        pos = get(s1,'Position');
        delete(s1);
        hax2 = copyobj(hax1,Avg_fig);
        set(hax2, 'Position', pos);
        set(Avg_fig, 'colormap', jet);
        drawnow;
        close(h);
        
    end
end

%% perform cluster test to identify ROI with task related alpha modulation
cfg = [];
cfg.dim = sourcesRef{1,1}.dim;
cfg.method = 'montecarlo';
cfg.statistic = 'ft_statfun_depsamplesT';
cfg.parameter = 'pow';
cfg.correctm = 'cluster';
cfg.numrandomization = 5000;
cfg.alpha = 0.01;
cfg.tail = 0;
cfg.design(1,:) = [1:length([idxSham idxStim]) 1:length([idxSham idxStim])];
cfg.design(2,:) = [ones(1,length([idxSham idxStim])) ones(1,length([idxSham idxStim]))*2];
cfg.uvar = 1;
cfg.ivar = 2;
cfg.computecritval = 'yes';
cfg.computeprob    = 'yes';
ERDstat = ft_sourcestatistics(cfg,sourcesTest{[idxSham idxStim],1}, sourcesRef{[idxSham idxStim],1});

%% plot cluster

cfg = [];
cfg.parameter = 'all';

statplot = ft_sourceinterpolate(cfg,ERDstat,mri);

cfg = [];
cfg.method = 'slice';
cfg.downsample = 1;
cfg.surfinflated = 'surface_inflated_both_caret.mat';
cfg.funparameter = 'stat';
cfg.maskparameter = 'mask';
cfg.camlight = 'no';
cfg.funcolormap = jet;
cfg.funcolorlim = [-5 5];
cfg.funcolormap = jet;

ft_sourceplot(cfg,statplot);

%% get mean power modulation within ROI for each subject
%ERDdata = cellfun(@(x) mean(x.pow(ERDstat{1,3}.mask)), sources);
ERDdata = cellfun(@(x) mean(x.pow(ERDstat.mask)), sources);
RefData = cellfun(@(x) mean(x.pow(ERDstat.mask)), sourcesRef);
TstData = cellfun(@(x) mean(x.pow(ERDstat.mask)), sourcesTest);

figure;
subplot(2,1,1);
plot(ERDdata(idxStim,:)','-'); hold on;
plot(ERDdata(idxSham,:)', ':');
plot(ERDdata(idxExcl,:), '--');
%ERDdata = ERDdata(2:21,:);

%% calculate power modulation relative to baseline
normERDdata = ERDdata ./ abs(repmat(ERDdata(:,1),1,size(ERDdata,2)))*100;
normRefData = RefData ./ abs(repmat(RefData(:,1),1,size(RefData,2)))*100;
normTstData = TstData ./ abs(repmat(TstData(:,1),1,size(TstData,2)))*100;

%% plot result
subplot(2,1,2);
plot(normERDdata(idxStim,:)', '-'); hold on;
plot(normERDdata(idxSham(1:end),:)', ':'); hold on;
plot(normERDdata(idxExcl,:)', '--');


%zscore(mean(normERDdata(:,2:end),2))
addpath(genpath('/data3/Florian/tMentRotNew/analysis/scripts/functions'));
%idxSham = idxSham(1:end-1);
figure;
errorbar(mean(normERDdata(idxStim([1:end]),:),1), sem(normERDdata(idxStim(1:end),:),[],1), 'r'); hold on;
errorbar(mean(normERDdata(idxSham(1:end),:),1), sem(normERDdata(idxSham(1:end),:),[],1), 'b'); hold on;

ERDdata = [ERDdata normERDdata RefData normRefData TstData normTstData];

%meanNoise{1} = mean(cell2mat(allNoise(idxStim)),2);
%meanNoise{2} = mean(cell2mat(allNoise(idxSham)),2);

Avg_powSpct(1,:,:) = squeeze(mean(mean(refPowSpctrm(ERDstat.mask(template_grid.inside),:,idxStim,:),1),3));
Avg_powSpct(2,:,:) = squeeze(mean(mean(tstPowSpctrm(ERDstat.mask(template_grid.inside),:,idxStim,:),1),3));
Avg_powSpct(3,:,:) = squeeze(mean(mean(refPowSpctrm(ERDstat.mask(template_grid.inside),:,idxSham,:),1),3));
Avg_powSpct(4,:,:) = squeeze(mean(mean(tstPowSpctrm(ERDstat.mask(template_grid.inside),:,idxSham,:),1),3));

SEM_powSpct(1,:,:) = squeeze(sem(mean(refPowSpctrm(ERDstat.mask(template_grid.inside),:,idxStim,:),1),[],3));
SEM_powSpct(2,:,:) = squeeze(sem(mean(tstPowSpctrm(ERDstat.mask(template_grid.inside),:,idxStim,:),1),[],3));
SEM_powSpct(3,:,:) = squeeze(sem(mean(refPowSpctrm(ERDstat.mask(template_grid.inside),:,idxSham,:),1),[],3));
SEM_powSpct(4,:,:) = squeeze(sem(mean(tstPowSpctrm(ERDstat.mask(template_grid.inside),:,idxSham,:),1),[],3));

%% Plot spectra and topos normalized to baseline ERD

Avg_normRelData = cell(2,7);
Avg_normscr = cell(2,7);
Avg_normint = cell(2,7);
normRelData = relData;
normSources = sources;

roi = find(ERDstat.mask(template_grid.inside));

normAvg_fig = figure;
%limits = [-2.5 2.5]*10e-22;
limits = [-300 300];
for blk = 1:7
    
    for sbj = 1:length(SUBJ)
        
        normRelData{sbj,blk}.powspctrm = relData{sbj,blk}.powspctrm / ERDdata(sbj,1)*100;
        
        normSources{sbj,blk}.pow = sources{sbj,blk}.pow / ERDdata(sbj,1)*100;
        
    end
    
    cfg = [];
    cfg.parameter = 'powspctrm';
    cfg.keepindividual = 'no';
    
    Avg_normRelData{1,blk} = ft_freqgrandaverage(cfg,normRelData{idxStim, blk});
    Avg_normRelData{2,blk} = ft_freqgrandaverage(cfg,normRelData{idxSham, blk});
    
    cfg = [];
    cfg.parameter = 'pow';
    cfg.keepindividual = 'no';
    
    Avg_normscr{1,blk} = ft_sourcegrandaverage(cfg,normSources{idxStim, blk});
    Avg_normscr{2,blk} = ft_sourcegrandaverage(cfg,normSources{idxSham, blk});
    
    Avg_normscr{1,blk}.mask = abs(ERDstat.stat);
    Avg_normscr{2,blk}.mask = abs(ERDstat.stat);
    
    cfg = [];
    cfg.parameter = {'pow', 'mask'};
    Avg_normint{1,blk} = ft_sourceinterpolate(cfg, Avg_normscr{1,blk}, mri);
    Avg_normint{2,blk} = ft_sourceinterpolate(cfg, Avg_normscr{2,blk}, mri);
    
%     Avg_normint{1,blk}.mask = abs(Avg_normint{1,blk}.pow);
%     Avg_normint{2,blk}.mask = abs(Avg_normint{2,blk}.pow);
%     Avg_normint{1,blk}.mask = ERDstat.mask;
%     Avg_normint{2,blk}.mask = ERDstat.mask;
    
    cfg = [];
    cfg.parameter = 'powspctrm';
    cfg.colormap = jet;
    %cfg.baseline = [-2.5 0];
    %cfg.baselinetype = 'relchange';
    cfg.zlim = limits;
    cfg.xlim = [-3 6];
    cfg.colorbar = 'no';
    cfg.channel = roi;
    figure(normAvg_fig);
    subplot(4,7,blk);
    ft_singleplotTFR(cfg,Avg_normRelData{1,blk}); hold on;
    plot([0 0], [3 28], 'w', 'LineWidth', 2);
    title(['Block ', num2str(blk)]);
    
    figure(normAvg_fig);
    subplot(4,7,blk+14);
    ft_singleplotTFR(cfg,Avg_normRelData{2,blk}); hold on;
    plot([0 0], [3 28], 'w', 'LineWidth', 2);
    title(['Block ', num2str(blk)]);
    
    
    cfg = [];
    cfg.funparameter = 'pow';
    cfg.method = 'slice';
    %cfg.method = 'surface';
    cfg.surfinflated = 'surface_inflated_both_caret.mat';
    cfg.nslices = 9;
    cfg.maskparameter = 'mask';
    cfg.funcolormap = jet;
    cfg.camlight = 'no';
    cfg.funcolorlim = limits;
    cfg.opacitymap = 'rampup';
    cfg.opacitylim = [ERDstat.critval(2) 5];
    ft_sourceplot(cfg,Avg_normint{1,blk});
    
    %view([-56 16]);
    h = gcf;
    hax1 = gca;
    figure(normAvg_fig);
    s1 = subplot(4,7,blk+7);
    pos = get(s1,'Position');
    delete(s1);
    hax2 = copyobj(hax1,normAvg_fig);
    set(hax2, 'Position', pos);
    set(normAvg_fig, 'colormap', jet);
    drawnow;
    close(h);
    
    cfg = [];
    cfg.funparameter = 'pow';
    cfg.method = 'slice';
    cfg.nslices = 9;
    cfg.maskparameter = 'mask';
    cfg.funcolormap = jet;
    cfg.camlight = 'no';
    %cfg.downsample = 10;
    cfg.funcolorlim = limits;
    cfg.opacitymap = 'rampup';
    cfg.opacitylim = [ERDstat.critval(2) 5];
    
    ft_sourceplot(cfg,Avg_normint{2,blk});
    %view([-56 16]);
    
    h = gcf;
    hax1 = gca;
    figure(normAvg_fig);
    s1 = subplot(4,7,blk+21);
    pos = get(s1,'Position');
    delete(s1);
    hax2 = copyobj(hax1,normAvg_fig);
    set(hax2, 'Position', pos);
    set(normAvg_fig, 'colormap', jet);
    drawnow;
    close(h);
        
end

%%

FreqVec = Avg_tfr{1,1}.freq;

figure;
for blk = 1:7
    
    subplot(2,7,blk);
    plot(FreqVec, Avg_powSpct(1,:,blk), 'r', 'LineWidth', 2); hold on; xlim([3, 25]); ylim([0, 8e-21]);
    plot(FreqVec, Avg_powSpct(2,:,blk), 'b', 'LineWidth', 2);
    if blk == 1
        xlabel('Frequency [Hz]');
        ylabel('Power [a.u.]');
        legend('Reference Period', 'Test Period');
    end
    boundedline(FreqVec, Avg_powSpct(1,:,blk), SEM_powSpct(1,:,blk), 'r', 'alpha'); hold on;
    boundedline(FreqVec, Avg_powSpct(2,:,blk), SEM_powSpct(2,:,blk), 'b','alpha');
    title(['Block ', num2str(blk)]);
    set(gca, 'XTickLabels', {'-5', 'IAF', '+5', '+10', '+15'});
    
    subplot(2,7,blk+7);
    plot(FreqVec, Avg_powSpct(3,:,blk), 'r', 'LineWidth', 2); hold on; xlim([3, 25]); ylim([0, 8e-21]);
    plot(FreqVec, Avg_powSpct(4,:,blk), 'b', 'LineWidth', 2);
    if blk == 1
        xlabel('Frequency [Hz]');
        ylabel('Power [a.u.]');
        legend('Reference Period', 'Test Period');
    end
    boundedline(FreqVec, Avg_powSpct(3,:,blk), SEM_powSpct(1,:,blk), 'r','alpha'); hold on; xlim([3, 25]); ylim([0, 8e-21]);
    boundedline(FreqVec, Avg_powSpct(4,:,blk), SEM_powSpct(2,:,blk), 'b','alpha');
    set(gca, 'XTickLabels', {'-5', 'IAF', '+5', '+10', '+15'});
    
end

disp('saving data...');
if doSave == 1
    
    save([PATHOUT, 'ERDavg.mat'], 'Avg_normint', 'Avg_normRelData', 'Avg_scr', 'Avg_int', 'Avg_tfr', 'relAvg_tfr', 'ERDstat', '-v7.3');
    csvwrite([MAINPATH, 'stats/ERDdata.csv'], ERDdata);
    
end
disp('...done!');