%% visualize results of the analyses.

clear;
close all;
clc;

normalized = 0;

MAINPATH = 'Z:\Florian\tMentRotNew\analysis\';
PATHIN = [MAINPATH, 'AVG\'];

addpath('Z:\Florian\fieldtrip');
ft_defaults;

filename = 'ERDavg.mat';

disp(['loading ', filename]);
load([PATHIN, filename]);
disp('done...');
dsF = 1;

load standard_mri.mat;
load mni_grid_1_5_cm_889pnts.mat

roi = find(ERDstat.mask(template_grid.inside));

ERDstat.stat(isnan(ERDstat.stat))=0;

ERDstat.mask = abs(ERDstat.stat);

%% Plot Statistical map
statFigStim = figure;
statFigSham = figure;
cfg = [];
cfg.parameter = 'all';
cfg.interpmethod = 'linear';
cfg.downsample = 1;
statplotDat = ft_sourceinterpolate(cfg,ERDstat,mri);

%statplotDat.mask = abs(statplotDat.stat);

cfgP = [];
cfgP.funparameter = 'pow';
cfgP.surffile = 'surface_white_right.mat';
cfgP.method = 'surface';
cfgP.maskparameter = 'mask';
cfgP.opacitymap = 'rampup';
cfgP.opacitylim = [ERDstat.critval(2) 5];
cfgP.funparameter = 'stat';
cfgP.funcolormap = jet;
cfgP.camlight = 'no';
cfgP.projmethod = 'nearest';
cfgP.projthresh = 0;  
cfgP.funcolorlim = [-7 7];

cfgP.surfinflated = 'surface_inflated_right_caret.mat';

ft_sourceplot(cfgP,statplotDat); axis tight;
view([56 16]);

h = gcf;
hax1 = gca;
figure(statFigStim);
s1 = subplot(1,4,2);
pos = get(s1,'Position');
delete(s1);
hax2 = copyobj(hax1,statFigStim);
set(hax2, 'Position', pos);
set(statFigStim, 'colormap', jet);
%title('Stimulation Group', 'FontSize', 24);
drawnow;
close(h);

cfgP.surffile = 'surface_white_left.mat';
cfgP.surfinflated = 'surface_inflated_left_caret.mat';

ft_sourceplot(cfgP,statplotDat); axis tight;
view([-56 16]);

h = gcf;
hax1 = gca;
figure(statFigStim);
s1 = subplot(1,4,1);
pos = get(s1,'Position');
delete(s1);
hax2 = copyobj(hax1,statFigStim);
set(hax2, 'Position', pos);
set(statFigStim, 'colormap', jet);
%title('Block 4 > Baseline', 'FontSize', 24);
drawnow;
close(h);

cfgP.surffile = 'surface_white_right.mat';
cfgP.surfinflated = 'surface_inflated_right_caret.mat';

ft_sourceplot(cfgP,statplotDat); axis tight;
view([-56 16]);

h = gcf;
hax1 = gca;
figure(statFigStim);
s1 = subplot(1,4,4);
pos = get(s1,'Position');
delete(s1);
hax2 = copyobj(hax1,statFigStim);
set(hax2, 'Position', pos);
set(statFigStim, 'colormap', jet);
drawnow;
close(h);

cfgP.surffile = 'surface_white_left.mat';
cfgP.surfinflated = 'surface_inflated_left_caret.mat';

ft_sourceplot(cfgP,statplotDat); axis tight;
view([56 16]);

h = gcf;
hax1 = gca;
figure(statFigStim);
s1 = subplot(1,4,3);
pos = get(s1,'Position');
delete(s1);
hax2 = copyobj(hax1,statFigStim);
set(hax2, 'Position', pos);
set(statFigStim, 'colormap', jet);
drawnow;
close(h);

c1 = colorbar('location','southoutside','AxisLocation', 'out', 'FontSize', 14*1.5);
c1.Label.String = 't-value';
c1.Label.FontSize = 16*1.5;
c1.Ticks = linspace(-5,5,3);
set(c1, 'position', [0.315 0.20, 0.40, 0.02]);

%% Plot normalized functional data (Burkhards way)

limits = [-500 500];

normAvg_fig = figure;
for blk = 1:length(Avg_int);
    
    if normalized == 0
        
        Avg_normint{1,blk}.pow =  Avg_normint{1,blk}.pow * -1;
        Avg_normint{2,blk}.pow =  Avg_normint{2,blk}.pow * -1;
        
    end
    
    cfg = [];
    cfg.parameter = 'powspctrm';
    cfg.colormap = jet;
    %cfg.baseline = [-2.5 0];
    %cfg.baselinetype = 'relchange';
    cfg.zlim = limits;
    cfg.xlim = [-2.5 4];
    cfg.colorbar = 'no';
    cfg.channel = roi;
    figure(normAvg_fig);
    subplot(4,7,blk);
    ft_singleplotTFR(cfg,Avg_normRelData{1,blk}); hold on;
    plot([0 0], [3 28], 'w', 'LineWidth', 2);
    title('');
    if blk == 1
        xlabel('Time [sec]');
        ylabel('Frequency [Hz]');
    end
    set(gca, 'YTickLabels', {'-5', 'IAF', '+5', '+10', '+15'}, 'FontSize', 16);
    
    cfg = [];
    cfg.funparameter = 'pow';
    %cfg.method = 'slice';
    cfg.method = 'surface';
    cfg.surfinflated = 'surface_inflated_both_caret.mat';
    cfg.nslices = 9;
    cfg.maskparameter = 'mask';
    cfg.funcolormap = jet;
    cfg.camlight = 'no';
    cfg.funcolorlim = limits;
    cfg.opacitymap = 'rampup';
    cfg.opacitylim = [ERDstat.critval(2) 5];
    ft_sourceplot(cfg,Avg_normint{1,blk}); axis tight;
    
    view([-56 16]);
    h = gcf;
    hax1 = gca;
    figure(normAvg_fig);
    s1 = subplot(4,7,blk+7);
    pos = get(s1,'Position');
    delete(s1);
    hax2 = copyobj(hax1,normAvg_fig);
    set(hax2, 'Position', pos);
    set(normAvg_fig, 'colormap', jet);
    drawnow;
    close(h);
    
      
    cfg = [];
    cfg.parameter = 'powspctrm';
    cfg.colormap = jet;
    %cfg.baseline = [-2.5 0];
    %cfg.baselinetype = 'relchange';
    cfg.zlim = limits;
    cfg.xlim = [-2.5 4];
    cfg.colorbar = 'no';
    cfg.channel = roi;
        figure(normAvg_fig);
    subplot(4,7,blk+14);
    ft_singleplotTFR(cfg,Avg_normRelData{2,blk}); hold on;
    plot([0 0], [3 28], 'w', 'LineWidth', 2);
    title('');
    
    if blk == 1
        xlabel('Time [sec]');
        ylabel('Frequency [Hz]');
    end
    set(gca, 'YTickLabels', {'-5', 'IAF', '+5', '+10', '+15'}, 'FontSize', 16);
    
    cfg = [];
    cfg.funparameter = 'pow';
    cfg.method = 'surface';
    cfg.surfinflated = 'surface_inflated_both_caret.mat';
    cfg.nslices = 9;
    cfg.maskparameter = 'mask';
    cfg.funcolormap = jet;
    cfg.camlight = 'no';
    %cfg.downsample = 10;
    cfg.funcolorlim = limits;
    cfg.opacitymap = 'rampup';
    cfg.opacitylim = [ERDstat.critval(2) 5];
    
    ft_sourceplot(cfg,Avg_normint{2,blk}); axis tight;
    view([-56 16]);
    
    h = gcf;
    hax1 = gca;
    figure(normAvg_fig);
    s1 = subplot(4,7,blk+21);
    pos = get(s1,'Position');
    delete(s1);
    hax2 = copyobj(hax1,normAvg_fig);
    set(hax2, 'Position', pos);
    set(normAvg_fig, 'colormap', jet);
    drawnow;
    close(h);
    
end

c1 = colorbar('AxisLocation', 'in', 'FontSize', 18);
c1.Label.String = 'Normalized \DeltaPower [%]';
c1.Label.FontSize = 18;
c1.Ticks = linspace(limits(1),limits(2),5);
%c1.TickLabels = linspace(-10,10,5);
set(c1, 'position', [0.96 0.1, 0.01, 0.85]);

normalized = 1;
%% Plot functional data
limits =  [-2.5 2.5]*10e-22;
Avg_fig = figure;
for blk = 1:length(Avg_int);
    
    figure(Avg_fig);
    subplot(4,7,blk);
    cfg = [];
    cfg.channel = roi;
    %cfg.baseline = [-2.5 0];
    %cfg.baselinetype = 'relchange';
    cfg.colorbar = 'no';
    cfg.colormap = jet;
    cfg.zlim = limits;
    cfg.xlim = [-3 4];
    ft_singleplotTFR(cfg,relAvg_tfr{1,blk}); hold on;
    plot([0 0], [3 28], 'w', 'LineWidth', 2);
    %title(['Block ', num2str(blk)], 'FontSize', 28);
    title('');
    if blk == 1
        xlabel('Time [sec]');
        ylabel('Frequency [Hz]');
    end
    set(gca, 'YTickLabels', {'-5', 'IAF', '+5', '+10', '+15'}, 'FontSize', 16);
    
    Avg_int{1,blk}.pow = Avg_int{1,blk}.pow*-1;
    Avg_int{2,blk}.pow = Avg_int{2,blk}.pow*-1;
    
    cfg = [];
    cfg.funparameter = 'pow';
    cfg.method = 'surface';
    cfg.maskparameter = 'mask';
    cfg.funcolormap = jet;
    cfg.camlight = 'no';
    cfg.downsample = dsF;
    cfg.funcolorlim = limits;
    cfg.surfinflated = 'surface_inflated_both_caret.mat';
    
    ft_sourceplot(cfg,Avg_int{1,blk}); axis tight;
    view([-56 16]);
    h = gcf;
    hax1 = gca;
    figure(Avg_fig);
    s1 = subplot(4,7,blk+7);
    pos = get(s1,'Position');
    delete(s1);
    hax2 = copyobj(hax1,Avg_fig);
    set(hax2, 'Position', pos);
    set(Avg_fig, 'colormap', jet);
    drawnow;
    close(h);
    
    figure(Avg_fig);
    subplot(4,7,blk+14);
    cfg = [];
    cfg.channel = roi;
    %cfg.baseline = [-2.5 0];
    %cfg.baselinetype = 'relchange';
    cfg.colorbar = 'no';
    cfg.colormap = jet;
    cfg.zlim = limits;
    cfg.xlim = [-3 4];
    ft_singleplotTFR(cfg,relAvg_tfr{2,blk}); hold on;
    plot([0 0], [3 28], 'w', 'LineWidth', 2);
    %title(['Block ', num2str(blk)], 'FontSize', 24);
    title('');
    if blk == 1
        xlabel('Time [sec]');
        ylabel('Frequency [Hz]');
    end
    set(gca, 'YTickLabels', {'-5', 'IAF', '+5', '+10', '+15'}, 'FontSize', 16);
    
    cfg = [];
    cfg.funparameter = 'pow';
    cfg.method = 'surface';
    cfg.maskparameter = 'mask';
    cfg.funcolormap = jet;
    cfg.camlight = 'no';
    cfg.downsample = dsF;
    cfg.funcolorlim =  limits;
    cfg.surfinflated = 'surface_inflated_both_caret.mat';
    
    ft_sourceplot(cfg,Avg_int{2,blk}); axis tight;
    view([-56 16]);
    
    h = gcf;
    hax1 = gca;
    figure(Avg_fig);
    s1 = subplot(4,7,blk+21);
    pos = get(s1,'Position');
    delete(s1);
    hax2 = copyobj(hax1,Avg_fig);
    set(hax2, 'Position', pos);
    set(Avg_fig, 'colormap', jet);
    drawnow;
    close(h);
end

c1 = colorbar('AxisLocation', 'in', 'FontSize', 18);
c1.Label.String = '\Delta Power [a.u.]';
c1.Label.FontSize = 18;
c1.Ticks = linspace(limits(1),limits(2),5);
c1.TickLabels = linspace(-10,10,5);
set(c1, 'position', [0.96 0.1, 0.01, 0.85]);

%% Plot raw
rawFig = figure;
zlimit = [0 5e-21];
for blk = 1:length(Avg_tfr)
    
    figure(rawFig);
    subplot(4,7,blk);
    cfg = [];
    cfg.channel = roi;
    %cfg.baseline = [0 4];
    %cfg.baselinetype = 'absolute';
    cfg.colorbar = 'no';
    cfg.colormap = jet;
    cfg.zlim = zlimit;
    cfg.xlim = [-3 4];
    ft_singleplotTFR(cfg,Avg_tfr{1,blk}); hold on;
    plot([0 0], [3 28], 'w', 'LineWidth', 2);
    %title(['Block ', num2str(blk)], 'FontSize', 14);
    title('');
    if blk == 1
        xlabel('Time [sec]');
        ylabel('Frequency [Hz]');
    end
    set(gca, 'YTickLabels', {'-5', 'IAF', '+5', '+10', '+15'}, 'FontSize', 16);
    
    foi = [8 12];
    foi = nearest(Avg_tfr{1,blk}.freq,foi);
    toi1 = [-2.5 -0.5];
    toi1 = nearest(Avg_tfr{1,blk}.time,toi1);
    toi2 = [0 2];
    toi2 = nearest(Avg_tfr{1,blk}.time,toi2);
    scr = template_grid;
    scr.pow = NaN(length(Avg_scr{1}.inside),1);
    scr.pow(scr.inside) = mean(mean(Avg_tfr{1,blk}.powspctrm(:,foi,toi1),3),2);% ./ meanNoise{1}(scr.inside);
    
    cfg = [];
    cfg.parameter = 'pow';
    
    scr_int = ft_sourceinterpolate(cfg,scr,mri);
    scr_int.mask = abs(scr_int.pow);
    
    cfg = [];
    cfg.method = 'surface';
    cfg.funparameter = 'pow';
    cfg.camlight = 'no';
    cfg.maskparameter = 'mask';
    cfg.funcolorlim = zlimit;
    cfg.funcolormap = jet;
    cfg.surfdownsample = dsF;
    cfg.colorbar = 'no';
    cfg.surfinflated = 'surface_inflated_both_caret.mat';
    ft_sourceplot(cfg,scr_int); axis tight;
    
    if strcmp(cfg.method, 'surface')
        view([-56,16]);
    end
    h = gcf;
    hax1 = gca;
    figure(rawFig);
    s1 = subplot(4,7,blk+7);
    pos = get(s1,'Position');
    delete(s1);
    hax2 = copyobj(hax1,rawFig);
    set(hax2,'Position', pos);
    set(rawFig,'colormap', jet);
    drawnow;
    close(h);
    
    figure(rawFig);
    subplot(4,7,blk+14);
    cfg = [];
    cfg.channel = roi;
    %cfg.baseline = [0 4];
    %cfg.baselinetype = 'absolute';
    cfg.colorbar = 'no';
    cfg.colormap = jet;
    cfg.zlim = zlimit;
    cfg.xlim = [-2.5 4];
    ft_singleplotTFR(cfg,Avg_tfr{2,blk}); hold on;
    plot([0 0], [3 28], 'w', 'LineWidth', 2);
    %title(['Block ', num2str(blk)], 'FontSize', 14);
    title('');
    if blk == 1;
        xlabel('Time [sec]');
        ylabel('Frequency [Hz]');
    end
    set(gca, 'YTickLabels', {'-5', 'IAF', '+5', '+10', '+15'}, 'FontSize', 16);
    
    foi = [8 12];
    foi = nearest(Avg_tfr{2,blk}.freq,foi);
    toi1 = [-2.5 -0.5];
    toi1 = nearest(Avg_tfr{1,blk}.time,toi1);
    toi2 = [0 2];
    toi2 = nearest(Avg_tfr{1,blk}.time,toi2);
    
    scr = template_grid;
    scr.pow = NaN(length(Avg_scr{1}.inside),1);
    scr.pow(scr.inside) = mean(mean(Avg_tfr{2,blk}.powspctrm(:,foi,toi1),3),2);% ./ meanNoise{1}(scr.inside);
    
    cfg = [];
    cfg.parameter = 'pow';
    
    scr_int = ft_sourceinterpolate(cfg,scr,mri);
    scr_int.mask = abs(scr_int.pow);
    
    cfg = [];
    cfg.method = 'surface';
    cfg.funparameter = 'pow';
    cfg.sphereradius = 100;
    cfg.camlight = 'no';
    cfg.maskparameter = 'mask';
    cfg.funcolorlim = zlimit;
    cfg.funcolormap = jet;
    cfg.downsample = dsF;
    cfg.colorbar = 'no';
    cfg.surfinflated = 'surface_inflated_both_caret.mat';
    ft_sourceplot(cfg,scr_int); axis tight;
    if strcmp(cfg.method, 'surface')
        view([-56,16]);
    end
    h = gcf;
    hax1 = gca;
    figure(rawFig);
    s1 = subplot(4,7,blk+21);
    pos = get(s1,'Position');
    delete(s1);
    hax2 = copyobj(hax1,rawFig);
    set(hax2,'Position', pos);
    set(rawFig,'colormap', jet);
    drawnow;
    close(h);
    
end
c1 = colorbar('AxisLocation', 'in', 'FontSize', 18);
c1.Label.String = 'NAI [a.u.]';
c1.Label.FontSize = 18;
c1.Ticks = linspace(zlimit(1),zlimit(2),6);
%c1.TickLabels = linspace(-10,10,5);
set(c1, 'position', [0.96 0.1, 0.01, 0.85]);
