function newMEG = mergeFIF(PATHIN, Infilename, extension)
% data = mergeFIF(PATHIN, filename) merges datasets automatically split by
% Neuromag recording system. This function uses functions from the
% FIELDTRIP toolbox, so please make sure it is installed and added to the
% Matlab search path. 
%
% PATHIN :      path to the datasets to be merged. All files have to be stored
%               in the same folder.
%
% filename:     basic filename without filetype extention and enumeration as automatically
%               created by the recorder. If your filenames are
%               'example01.fif', 'example01-1.fif' and 'example02-2.fif' only
%               specify 'example01' here.
%
% AUTHOR: Florian Kasten, 2015

COND = {'1', '2', '-11', '-12', '-21'};

% initialize cell arrays for MEG and event data
MEG = cell(1,length(COND));
events = cell(1,length(COND));
len = 0;
% load datasets to be merged
parfor set = 1:length(COND)
   
    filename = [Infilename, COND{set}, extension];
    
    cfg = [];
    
    cfg.dataset = [PATHIN, filename];
    
    MEG{set} = ft_preprocessing(cfg);
    
    events{set} = ft_read_event([PATHIN,filename]);
    
    len = len+length(MEG{set}.trial{1,1});
    
end

%% merge data from loaded datasets into one large trial
% create new MEG structure with information copied from the first dataset
MEG{2}.trial{1}(:,MEG{1}.sampleinfo(1):MEG{1}.sampleinfo(2)) = MEG{1}.trial{1};
newMEG = MEG{2};
% allocate memory for MEG raw data
newMEG.trial{1,1} = zeros(length(MEG{1}.label),len);
% merge MEG rawdata into one long trial
newMEG.trial{1,1} = horzcat(MEG{2}.trial{1,1}, MEG{3}.trial{1,1}, MEG{4}.trial{1,1}, MEG{5}.trial{1,1});

% update sampleinformation
newMEG.sampleinfo = [1 length(newMEG.trial{1,1})];

% update timeline
for i = 2:newMEG.sampleinfo(2); %NOTE: Loop assumes data has yet to be downsampled and is at the base SR of 1000Hz.
newMEG.time{1,1}(1,i) = (i - 1)/newMEG.fsample; %Change .001 to match SR.? 
end 

events{2} = vertcat(events{1}, events{2});

sInfo = 0;
for j = 3:length(COND)
    sInfo = sInfo + MEG{j-1}.sampleinfo(2);
% adapt event latencies to new timeline
for i = 1:length([events{1,j}.sample])
    events{1,j}(i).sample = [events{1,j}(i).sample] + sInfo;
end

end

% delete MEG array from workspace to save memory
clear('MEG');

% merge event structures
newEvents = vertcat(events{1,2}, events{1,3}, events{1,4}, events{1,5});

% add event structure to output MEG stucture
newMEG.event = newEvents;

end

